=========
Changelog
=========

Version 0.
===========

- Updating React and front end dependencies
- separated JS code from PY code moved front end to top level folder
- Removed webpack in favor of CRA for less complexity and faster dev work

Version 0.2
===========

- More effects and support for UDP devices
- Frontend converted to react and more features added

Version 0.1
===========

- Initial release with basic feature set!
    - Added a framework for highly customizable effects and outputs
    - Added support for E1.31 devices
    - Added some basic effects and audio reaction ones
